
%% Information
% SAS Model: Type-A Adv. Virgo-like structure
% Plots    : Transfer function from ground to TM

%% Frequency List
fmin=-2.5;fmax=1;
freq=logspace(fmin,fmax,1001);

%% Input & Output Port Setting
numi1=find(strcmp('azg',varinput));
numo1=find(strcmp('zTM',varoutput));

%% Passive Model
[mag1,phs1]=mybodeacc(sysp(numo1,numi1),freq); % zg -> zTM

%% Feedback Model
[mag2,phs2]  =mybodeacc(sysfb(26, 3),freq); % zg     -> zTM
[mag31,phs31]=mybode   (sysfb(26,10),freq); % snF0G1 -> zTM
[mag32,phs32]=mybode   (sysfb(26,11),freq); % snF0G2 -> zTM
[mag33,phs33]=mybode   (sysfb(26,12),freq); % snF0G3 -> zTM
[mag41,phs41]=mybode   (sysfb(26, 7),freq); % snF0L1 -> zTM
[mag42,phs42]=mybode   (sysfb(26, 8),freq); % snF0L2 -> zTM
[mag43,phs43]=mybode   (sysfb(26, 9),freq); % snF0L3 -> zTM
[mag51,phs51]=mybode   (sysfb(26,28),freq); % anF0c1 -> zTM
[mag52,phs52]=mybode   (sysfb(26,29),freq); % anF0c2 -> zTM
[mag53,phs53]=mybode   (sysfb(26,30),freq); % anF0c3 -> zTM

%% High Pass Filter
wRLF = 2*pi*0.05; % 50 mHz
filter_LFreject = zpk([0;0],wRLF*[-1;-1],1);
[magHP,phHP]    = mybode(filter_LFreject,freq);

%% Import
kamioka =importdata('noisepsd\kamiokaNoisy.txt');
geophone=importdata('noisepsd\GeoNoiseVolt.txt');
LVDT    =importdata('noisepsd\LVDTNoiseVolt.txt');
ACTF0   =importdata('noisepsd\ACTF0Volt.txt');
%OSEM    =importdata('noisepsd\OSEMNoise.txt');

%% Noise Level
noise_seism0=interp1(kamioka(:,1),kamioka(:,2),freq'); % [m/rtHz]
noise_seism = magHP.*noise_seism0;      % PSD with low freq rejection
rms_seism  =makerms(freq,noise_seism); % RMS

noise_geo   =interp1(geophone(:,1),geophone(:,2),freq'); % [V/rtHz]
noise_LVDT  =interp1(LVDT(:,1),LVDT(:,2),freq');         % [V/rtHz]
noise_ACTF0 =interp1(ACTF0(:,1),ACTF0(:,2),freq');       % [V/rtHz]

%% Noise on TM

nTM_seismp  =mag1.*noise_seism;        % Passive Seismic
rmsTM_seismp=makerms(freq,nTM_seismp);
rmsTM_seismp_vel=makermsvel(freq,nTM_seismp);

nTM_seism   =mag2.*noise_seism;          % Active Seismic
rmsTM_seism =makerms(freq,nTM_seism);

mag3 = sqrt(mag31.^2+mag32.^2+mag33.^2);
nTM_geo     =mag3.*noise_geo;            % GEO Noise
rmsTM_geo   =makerms(freq,nTM_geo);

mag4 = sqrt(mag41.^2+mag42.^2+mag43.^2);
nTM_LVDT    =mag4.*noise_LVDT;           % LVDT Noise
rmsTM_LVDT  =makerms(freq,nTM_LVDT);

mag5 = sqrt(mag51.^2+mag52.^2+mag53.^2);
nTM_ACTF0   =mag5.*noise_ACTF0;           % LVDT Noise
rmsTM_ACTF0 =makerms(freq,nTM_ACTF0);

nTM_total = sqrt(nTM_seism.^2+nTM_geo.^2+nTM_LVDT.^2+nTM_ACTF0.^2);
rmsTM_total =makerms(freq,nTM_total);
rmsTM_total_vel=makermsvel(freq,nTM_total);

%% Plot 3

magmin=-15;magmax=-4;
figure(601001); % PSD-AdvLikeZ-seismTM,geophone
  loglog(freq,nTM_seism,'b-',freq,rmsTM_seism,'c--',...
         freq,nTM_geo,'r-',freq,rmsTM_geo,'m--',...
         freq,nTM_LVDT,'g-',freq,rmsTM_LVDT,'y--',...
         freq,nTM_ACTF0,'k-',freq,rmsTM_ACTF0,'k--','LineWidth',2)
  legend('Seisic Noise','Seismic RMS','GEO Noise','GEO RMS',...
      'LVDT Noise','LVDT RMS','Act Noise','Act RMS','Location','SouthWest')
  grid on
  set(gca,'YTick',logspace(magmin,magmax,magmax-magmin+1))
  ylim([10^(magmin) 10^(magmax)])
  xlim([10^(fmin) 10^(fmax)])
  title('Transfer Function: zGround -> zTM','FontSize',16,'FontWeight','bold')
  ylabel('Magnitude','FontSize',14,'FontWeight','bold')
  set(gca,'FontSize',14)


%% Plot 2

magmin=-15;magmax=-4;
figure(601002); % PSD-AdvLikeZ-seismTM
  loglog(freq,nTM_seismp,'b-',freq,rmsTM_seismp,'c--',freq,rmsTM_seismp_vel,'b--',...
      freq,nTM_total,'r-',freq,rmsTM_total,'m--',freq,rmsTM_total_vel,'r--',...
      freq,noise_seism,'k-',freq,rms_seism,'g--','LineWidth',2)
  legend('Passive','Passive RMS','Passive V RMS','Active ON','Active RMS','Active V RMS',...
      'Ground','GND RMS','Location','SouthWest')
  grid on
  set(gca,'YTick',logspace(magmin,magmax,magmax-magmin+1))
  ylim([10^(magmin) 10^(magmax)])
  xlim([10^(fmin) 10^(fmax)])
  title('Transfer Function: zGround -> zTM','FontSize',16,'FontWeight','bold')
  ylabel('Magnitude','FontSize',14,'FontWeight','bold')
  set(gca,'FontSize',14)
